package cn.estsh.i3plus.ext.mes.apiservice.serviceimpl.base;

import cn.estsh.i3plus.ext.mes.api.base.IMesNumberRuleService;
import cn.estsh.i3plus.ext.mes.apiservice.unit.exception.MesException;
import cn.estsh.i3plus.pojo.base.bean.DdlPackBean;
import cn.estsh.i3plus.pojo.base.tool.DdlPreparedPack;
import cn.estsh.i3plus.pojo.mes.bean.MesNumberRule;
import cn.estsh.impp.framework.boot.util.ValidatorBean;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

/**
 * @Description : 规则代码
 * @Reference :
 * @Author : junsheng.li
 * @CreateDate 2024/6/13 11:19
 * @Modify:
 **/
@Service
@Slf4j
public class MesNumberRuleServiceImpl extends BaseMesService<MesNumberRule> implements IMesNumberRuleService {

    @Override
    protected void setPackQueryBean(MesNumberRule bean, DdlPackBean packBean) {
        DdlPreparedPack.getStringLikerPack(bean.getRuleCode(), "ruleCode", packBean);
        DdlPreparedPack.getStringLikerPack(bean.getPrefix(), "prefix", packBean);
        DdlPreparedPack.getStringLikerPack(bean.getNumberRule(), "numberRule", packBean);
        DdlPreparedPack.getNumEqualPack(bean.getIsCycle(), "isCycle", packBean);
    }

    @Override
    protected void onInsertBean(MesNumberRule item) {
        // 数据校验
        checkNotNull(item);

        DdlPackBean packBean = DdlPackBean.getDdlPackBean(item.getOrganizeCode());
        DdlPreparedPack.getStringLikerPack(item.getRuleCode(), "ruleCode", packBean);

        if (baseRDao.isExitByHql(packBean)) {
            MesException.throwMesBusiException("规则代码【%s】数据已存在", item.getRuleCode());
        }
    }

    @Override
    protected void onUpdateBean(MesNumberRule item) {
        // 数据校验
        checkNotNull(item);

        DdlPackBean ddlPackBean = DdlPackBean.getDdlPackBean(item.getOrganizeCode());
        DdlPreparedPack.getStringLikerPack(item.getRuleCode(), "ruleCode", ddlPackBean);
        DdlPreparedPack.getNumNOEqualPack(item.getId(), "id", ddlPackBean);

        if (baseRDao.isExitByHql(ddlPackBean)) {
            MesException.throwMesBusiException("规则代码【%s】数据已存在", item.getRuleCode());
        }
    }

    private void checkNotNull(MesNumberRule item) {
        ValidatorBean.checkNotNull(item.getRuleCode(), "规则代码不能为空");
    }
}
